@@ -6,6 +6,7 @@ INVALID_FLOAT_MSG = "ERR value is not a valid float"
 INVALID_OFFSET_MSG = "ERR offset is out of range"
 INVALID_BIT_OFFSET_MSG = "ERR bit offset is not an integer or out of range"
 INVALID_BIT_VALUE_MSG = "ERR bit is not an integer or out of range"
+BITOP_NOT_ONE_KEY_ONLY = "ERR BITOP NOT must be called with a single source key"
 INVALID_DB_MSG = "ERR DB index is out of range"
 INVALID_MIN_MAX_FLOAT_MSG = "ERR min or max is not a float"
 INVALID_MIN_MAX_STR_MSG = "ERR min or max not a valid string range item"
@@ -53,7 +54,7 @@ JSON_WRONG_REDIS_TYPE = "ERR Existing key has wrong Redis type"
 JSON_KEY_NOT_FOUND = "ERR could not perform this operation on a key that doesn't exist"
 JSON_PATH_NOT_FOUND_OR_NOT_STRING = "ERR Path '{}' does not exist or not a string"
 JSON_PATH_DOES_NOT_EXIST = "ERR Path '{}' does not exist"
-
+LCS_CANT_HAVE_BOTH_LEN_AND_IDX = "ERR If you want both the length and indexes, please just use IDX."
 FLAG_NO_SCRIPT = 's'  # Command not allowed in scripts
 FLAG_LEAVE_EMPTY_VAL = 'v'
 FLAG_TRANSACTION = 't'
